/**
 * Source File Name = TestJDBCVersion.java                                         
 * Licensed Materials - Property of IBM                                    
 * US Government Users Restricted Rights - Use, duplication or              
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.        
 *                                                                           
 *                                                                         
 * PURPOSE:          Test JDBC Version Driver          
 */

import java.sql.*;
import java.util.*;

public class TestJDBCVersion {
    /**
     * Returns JDBC Driver Version
     * 
     * @param con
     * @return 
     * @exception SQLException
     * @see     Generate
     * @see     GenerateC
     * @see     Retrieve
     * @see     Shred
     */

    public static String getJDBCDriverVersion( Connection con ) 
    throws SQLException {
        DatabaseMetaData  dbmd = null;
        if ( con != null )
            dbmd = con.getMetaData();

        String    JDBCVersion = null;
        /*
          - Obtain driver name from DatabaseMetaData.
          - Parse to obtain version number.
        */

        if ((dbmd != null) && 
            (( JDBCVersion =  dbmd.getDriverName()) != null )) {

            //System.out.println( "JDBCV = " + JDBCVersion );
            StringTokenizer strTok = new StringTokenizer( JDBCVersion );
            String          tokenValue  = null; 


            while ( strTok.hasMoreElements() == true ) {
                tokenValue = strTok.nextToken(); 
                // System.out.println( "Token = " + tokenValue );
                if ( tokenValue.equalsIgnoreCase( "JDBC" ) ) {
                    if ( strTok.hasMoreElements() == true ) {
                        //    System.out.println( "Token1 = " + tokenValue );
                        tokenValue = strTok.nextToken();//Get Number version
                        break;
                    }
                }
            }
            JDBCVersion = tokenValue;
        }
        return JDBCVersion;
    }

    public static void main( String[] argv ){
        if ( argv.length != 1 ) {
            System.out.println( "Usage: TestJDBCVersion database" );
            System.exit( 0 );
        }

        try {
            Class.forName ("COM.ibm.db2.jdbc.app.DB2Driver").newInstance ();

            Connection con = null;
            String url = "jdbc:db2:"+ argv[0];

            con = DriverManager.getConnection(url);

            System.out.println( "JDBC Version = \"" +
                                TestJDBCVersion.getJDBCDriverVersion( con ) + "\"" );
        } catch ( SQLException e ) {
            e.printStackTrace();
        } catch ( InstantiationException e ) {
            e.printStackTrace();
        } catch ( ClassNotFoundException e ) {
            e.printStackTrace();
        } catch ( IllegalAccessException e ) {
            e.printStackTrace();
        }

    }
}
